#!/usr/bin/env python

from distutils.core import setup

setup(name='django-model-repr',
      version='0.0.3',
      description='A django library for Model\'s __repr__ to be more informative',
      author='Larry Kim',
      author_email='pypi@relip.org',
      packages=['django_model_repr'],
)
